
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.26.2',
    'branch_nick': 'release-1.26-LTS',
    'revision_id': '3158a0ffb31aecd80a012eda5cc140ce0c263104',
    'revno': 10820
}
